This represents a function that can be used as input to an operation.
Arguments
- inputs
(
FuncInputs)
The inputs of the function.- lines
(
character())
The rendered op lines of the function body.
This represents a function that can be used as input to an operation.
(FuncInputs)
The inputs of the function.
(character())
The rendered op lines of the function body.