Skip to contents

Calls a named function from within the current function being built. The callee must already be finalized via hlo_return.

Usage

infer_types_call(callee, ...)

hlo_call(callee, ..., simplify = TRUE)

Arguments

callee

(Func)
The function to call. Must be a finalized Func.

...

(FuncValue)
The arguments to pass to the callee.

simplify

(logical(1))
If TRUE (default) and the callee has a single output, return a single FuncValue instead of a list.

Value

FuncValue or list() of FuncValues.