Skip to contents

Usage

hlo_cholesky(operand, lower, output_types = NULL)

Arguments

operand, lower

(FuncValue)

output_types

(list() of ValueType | NULL)
Output types known ahead of time (e.g. from type inference at trace time). When provided, type inference and its input validation are skipped.

Value

FuncValue

Details

The values of the other half of the matrix are not guaranteed and backend dependent.