Skip to contents

Infer the types for binary operations taking integers only. Unlike infer_types_integerish_biv(), booleans are not accepted: the bit-shift operations take a tensor of integer type, which in the StableHLO spec does not include i1.

Usage

infer_types_integer_biv(lhs, rhs)

Arguments

lhs

(ValueType)
The left-hand side operand.

rhs

(ValueType)
The right-hand side operand.

Value

(ValueType)
The inferred type.