This represents the name of a ValueType.
Arguments
- id
(
character(1)orNULL)
Either a fixed name orNULL(default). ANULLid is assigned a numeric name lazily when the program is rendered (repr()), in the order ids first appear:%0,%1, ..., skipping any integer already claimed by a named id in the same program (e.g. an input called"2").