R/op-call.R
hlo_call.Rd
Calls a named function from within the current function being built. The callee must already be finalized via hlo_return.
hlo_return
infer_types_call(callee, ...) hlo_call(callee, ..., simplify = TRUE)
(Func) The function to call. Must be a finalized Func.
Func
(FuncValue) The arguments to pass to the callee.
FuncValue
(logical(1)) If TRUE (default) and the callee has a single output, return a single FuncValue instead of a list.
logical(1)
TRUE
FuncValue or list() of FuncValues.
list()