See https://openxla.org/stablehlo/spec#dot_general for details.
Usage
infer_types_dot_general(
lhs,
rhs,
dot_dimension_numbers,
precision_config = NULL
)
hlo_dot_general(
lhs,
rhs,
contracting_dims,
batching_dims = NULL,
precision_config = NULL,
output_types = NULL
)Arguments
- lhs, rhs, contracting_dims, batching_dims
- dot_dimension_numbers
(
DotDimensionNumbers)
The dot dimension number.- precision_config
(
character()|NULL)
The precision configuration, a character vector of length 2 giving the precision used forlhsandrhs. Each entry must be one of"DEFAULT","HIGH"or"HIGHEST". IfNULL(default), no precision configuration is emitted, which is equivalent to"DEFAULT"for both operands.- output_types
(
list()ofValueType|NULL)
Output types known ahead of time (e.g. from type inference at trace time). When provided, type inference and its input validation are skipped.