Infer the types for binary operations taking integers only.
Unlike infer_types_integerish_biv(), booleans are not accepted: the
bit-shift operations take a tensor of integer type, which in the
StableHLO spec does not include i1.
Infer the types for binary operations taking integers only.
Unlike infer_types_integerish_biv(), booleans are not accepted: the
bit-shift operations take a tensor of integer type, which in the
StableHLO spec does not include i1.